==> CreativeCore_NEOFORGE_SOURCE_v2.13.18_mc1.21.1.jar: team/creative/creativecore/common/util/registry/LocatedHandlerRegistry.java <==
package team.creative.creativecore.common.util.registry;

import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.Map.Entry;
import java.util.Set;

import net.minecraft.resources.ResourceLocation;

public class LocatedHandlerRegistry<T> {
    
    private final HashMap<ResourceLocation, T> handlers = new LinkedHashMap<>();
    private final HashMap<T, ResourceLocation> handlersInv = new LinkedHashMap<>();
    private T defaultHandler;
    private boolean allowOverwrite = false;
    
    public LocatedHandlerRegistry(T handler) {
        this.defaultHandler = handler;
    }
    
    public LocatedHandlerRegistry<T> allowOverwrite() {
        allowOverwrite = true;
        return this;
    }
    
    public T getDefault() {
        return defaultHandler;
    }
    
    public void register(ResourceLocation id, T handler) {
        if (!allowOverwrite && handlers.containsKey(id))
            throw new IllegalArgumentException("'" + id + "' already exists");
        handlers.put(id, handler);
        handlersInv.put(handler, id);
    }
    
    public void registerDefault(ResourceLocation id, T handler) {
        defaultHandler = handler;
        register(id, handler);
    }
    
    public ResourceLocation getLocation(T type) {
        return handlersInv.get(type);
    }
    
    public T get(ResourceLocation id) {
        return handlers.getOrDefault(id, defaultHandler);
    }
    
    public T getOrThrow(ResourceLocation id) {
        T handler = handlers.get(id);
        if (handler == null)
            throw new IllegalArgumentException("'" + id + "' does not exist");
        return handler;
    }
    
    public boolean contains(ResourceLocation id) {
        return handlers.containsKey(id);
    }
    
    public Collection<ResourceLocation> keys() {
        return handlers.keySet();
    }
    
    public Set<Entry<ResourceLocation, T>> entrySet() {
        return handlers.entrySet();
    }
    
    public Collection<T> values() {
        return handlers.values();
    }
}

==> CreativeCore_NEOFORGE_SOURCE_v2.14.9_mc1.21.11.jar: team/creative/creativecore/common/util/registry/LocatedHandlerRegistry.java <==
package team.creative.creativecore.common.util.registry;

import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.Map.Entry;
import java.util.Set;

import net.minecraft.resources.Identifier;

public class LocatedHandlerRegistry<T> {
    
    private final HashMap<Identifier, T> handlers = new LinkedHashMap<>();
    private final HashMap<T, Identifier> handlersInv = new LinkedHashMap<>();
    private T defaultHandler;
    private boolean allowOverwrite = false;
    
    public LocatedHandlerRegistry(T handler) {
        this.defaultHandler = handler;
    }
    
    public LocatedHandlerRegistry<T> allowOverwrite() {
        allowOverwrite = true;
        return this;
    }
    
    public T getDefault() {
        return defaultHandler;
    }
    
    public void register(Identifier id, T handler) {
        if (!allowOverwrite && handlers.containsKey(id))
            throw new IllegalArgumentException("'" + id + "' already exists");
        handlers.put(id, handler);
        handlersInv.put(handler, id);
    }
    
    public void registerDefault(Identifier id, T handler) {
        defaultHandler = handler;
        register(id, handler);
    }
    
    public Identifier getLocation(T type) {
        return handlersInv.get(type);
    }
    
    public T get(Identifier id) {
        return handlers.getOrDefault(id, defaultHandler);
    }
    
    public T getOrThrow(Identifier id) {
        T handler = handlers.get(id);
        if (handler == null)
            throw new IllegalArgumentException("'" + id + "' does not exist");
        return handler;
    }
    
    public boolean contains(Identifier id) {
        return handlers.containsKey(id);
    }
    
    public Collection<Identifier> keys() {
        return handlers.keySet();
    }
    
    public Set<Entry<Identifier, T>> entrySet() {
        return handlers.entrySet();
    }
    
    public Collection<T> values() {
        return handlers.values();
    }
}
